#
# spec file for package gap-groupoids
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gap-groupoids
Version:        1.76
Release:        1.2
Summary:        GAP: Groupoids, graphs of groups, and graphs of groupoids
License:        GPL-2.0-or-later
Group:          Productivity/Scientific/Math
URL:            https://gap-packages.github.io/groupoids/
#Git-Clone:     https://github.com/gap-packages/groupoids
Source:         https://github.com/gap-packages/groupoids/releases/download/v%version/groupoids-%version.tar.gz
BuildArch:      noarch
BuildRequires:  gap-rpm-devel
Requires:       gap-autodoc >= 2019.02.22
Requires:       gap-core >= 4.10.1
Requires:       gap-fga >= 1.4.0
Requires:       gap-utils >= 0.76
Suggests:       gap-semigroups >= 3.1.1

%description
This package allows for the computation of finite groupoids, both
connected and with several components. Graphs of groups and graphs of
groupoids are also constructed, allowing the calculation of normal
forms for Free Products with Amalgamation and for HNN extensions when
the initial groups have rewriting systems.

%prep
%autosetup -n groupoids-%version

%build

%install
rm -Rf scripts
%gappkg_simple_install

%files -f %name.files

%changelog
* Mon Sep 23 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.76
  * fix error caused re immutable ExtRepOfObj
* Wed Jan 24 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.74
  * Avoid trivial function wrappers
* Sun Jun 25 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.73
  * Basic double groupoids
  * Added RegularActionHomomorphismGroupoid and used in gpdhom.tst
* Sat Feb 11 2023 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.72
  * moved attempt at double groupoids to XMod
  * added RegularActionHomomorphismGroupoid and used in gpdhom.tst
* Sat Nov 19 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 1.71
  * Renamed GpdIsDigraph etc as IsGroupoidDigraph
  * Replaced IsDiscrete by IsDiscreteMagmaWithObjects
  * Changed nicemap.tst to cope with alternative NiceMonomorphisms
* Wed Nov 14 2018 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 1.63
  * Corrections to methods for RightCoset and LeftCoset
  * Removed HomsetCosetsGroupoidCoset + old IsHomsetCosetsType
  * Operation RayElementsOfGroupoid is now Attribute RaysOfGroupoid
    and Attribute RaysOfGroupoid is now Operation RayArrowsOfGroupoid.
  * Changed HomsetCosets from IsPositionalObjectRep;
    corrected SubgroupoidByPieces when rays are involved
  * Add IsomorphismNewObjects method for hom discrete
    methods for \in for AutomorphismGroupOfGroupoid
  * Added property IsAutomorphismGroupOfGroupoidAsGroupoid
  * Added method for \in for automorphisms of groupoids
  * Added attribute PieceIsomorphisms for homogeneous dwos
  * Added attribute ParentMappingGroupoids for restricted mappings
  * Added GroupoidAutomorphismByObjectPerm method for groupoid with
    rays.
  * Removed attribute InverseOfIsomorphismFpSemigroup
  * Added AutomorphismGroupoidOfGroupoid for homogeneous groupoids
  * Replaced SmallGroup(8,4) with QuaternionGroup(8)
  * Added 'GGRWS' to 'FreeProductWithAmalgamation', 'HnnExtension'
  * Added ReducedImageElm for IsMappingToFreeProductWithAmalgamation
    IsFpaGroup now IsFreeProductWithAmalgamation; sim. IsHnnGroup.
* Sun Dec 24 2017 jengelh@inai.de
- Update to new upstream release 1.54
  * added MappingGeneratorsImages method for hom discrete mappings
  * added other method for GroupoidInnerAutomorphism(R,S,r);
  * added method for RestrictedMappingGroupoids for homdisc
  * added DirectProductOp for groupoids; Projection & Embedding
  * added MappingWithObjectsByFunction and associated prop/attr and
    then added new manual section on the inner automorphism group
  * added operation GroupoidInnerAutomorphism
* Fri Sep  8 2017 jengelh@inai.de
- The package was renamed from gpd to groupoids upstream
- Update to new upstream release 1.51
  * added various methods for String, ViewString, PrintString
* Sat Apr 29 2017 jengelh@inai.de
- Update to new upstream release 1.46
  * Removed method for IsCommutative from gpd.gi which was causing
    slowdown in the main GAP tests.
* Mon Nov 21 2016 jengelh@inai.de
- Update to new upstream release 1.45
  * improved RestrictedMappingGroupoids
  * Added IsomorphismStandardGroupoid to gpdhom.g{d,i};
    GroupoidAutomorphismByRayImages->GroupoidAutomorphismByRayShifts;
    SinglePieceGroupoidByGenerators->SinglePiceSubgroupoidByGenerators;
    improved RestrictedMappingGroupoids
  * ImagesOfRays renamed ImageElementsOfRays
  * Replaced Image(hom,x) with ImageElm(hom,x) throughout
  * Moved AutomorphismGroup methods to AutomorphismGroupOfGroupoid
  * Added EmbeddingsInNiceObject
  * Converted cases of \in to new InAutomorphismGroupOfGroupoid
* Sun Jun 19 2016 jengelh@inai.de
- Update to new upstream release 1.43
  * dealt with new diffs in test files
* Fri Mar 11 2016 jengelh@inai.de
- Update to new upstream release 1.42
  * new method for ObjectGroupHomomorphism
  * converted RootObject from an operation to an attribute
  * renamed IsDigraph etc as GpdIsDigraph
  * RestrictionMappingGroupoids -> RestrictedMappingGroupoids
  * added method for WeightedAdjacencyMatrix for FpWeightedDigraphs
  * added PrintObj & Viewobj for groupoid right cosets
  * removed RestrictionMappingGroups: now GeneralRestrictedMapping
  * replacing test IsScalar for objects with IsObject/IsSet
  added examples in section 4.1.1 where the objects are
  free group generators or strings
  * Added method for ImagesRepresentative( gpdhom, arrow )
* Tue Aug  4 2015 jengelh@inai.de
- Update to new upstream release 1.34
  * added method for GeneratorsOfMagma for a magma with objects
  * attempted fix of problem with NormalFormGGRWS
  * PackageInfo.g: Kan is now an accepted package
  * converted the bibliography to BibXMLext format and added an URL
  to Emma's thesis (moore.ps.gz)
  * changed 'InversesIfNonzero' to 'Inverse' in category names
* Sun Feb 22 2015 jengelh@inai.de
- Update to new upstream release 1.31
  * rays were inadvertently arrows, so swapped the names:
  RaysOfGroupoid with RayElementsOfGroupoid
  * added second Kd8method for IsHomogeneousDomainWithObjects
  * renamed MultiplicativeElementWithObjects as Arrow,
  IsElementOfMagmaWithObjects as IsArrowIn,
  GroupoidElement no longer needed: use Arrow,
  IdentityElement as IdentityArrow,
  ConjugateGroupoidElement as ConjugateArrow.
  * changed Arrow to ArrowNC in GeneratorsOfMagmaWithObjects
* Wed Feb  5 2014 jengelh@inai.de
- Update to new upstream release 1.22
  * Adjusted flip function in mwohom.g and mwohom.tst.
  * Added method for ImageElm for mwohoms and more than one piece.
  * Added IsElementOfMagmaWithObjects (in place of \in).
  * Renamed Arrowelt -> ElementOfArrow, etc.
* Fri May 10 2013 jengelh@inai.de
- Split gpd (version 1.19) off the gap RPM package
